@@ -18,8 +18,6 @@
 #![allow(clippy::vec_box)]
 #![allow(unstable_name_collisions)]
 
-use mode::Minification;
-use pass::postcompress::postcompress_optimizer;
 use swc_common::{comments::Comments, sync::Lrc, SourceMap, SyntaxContext, GLOBALS};
 use swc_ecma_ast::Module;
 use swc_ecma_visit::{FoldWith, VisitMutWith};
@@ -31,11 +29,12 @@ use crate::{
     compress::compressor,
     marks::Marks,
     metadata::info_marker,
+    mode::Minification,
     option::{ExtraOptions, MinifyOptions},
     pass::{
         compute_char_freq::compute_char_freq, expand_names::name_expander, global_defs,
-        mangle_names::name_mangler, mangle_props::mangle_properties,
-        precompress::precompress_optimizer,
+        mangle_names::name_mangler, mangle_props::mangle_properties, merge_exports::merge_exports,
+        postcompress::postcompress_optimizer, precompress::precompress_optimizer,
     },
 };
 
@@ -163,6 +162,8 @@ pub fn optimize(
         mangle_properties(&mut m, property_mangle_options.clone());
     }
 
+    m.visit_mut_with(&mut merge_exports());
+
     if let Some(ref mut t) = timings {
         t.section("hygiene");
     }
